@@ -1,7 +1,7 @@
 package Role::TinyCommons::Tree::FromStruct;
 
 our $DATE = '2016-03-22'; # DATE
-our $VERSION = '0.02'; # VERSION
+our $VERSION = '0.03'; # VERSION
 
 use Role::Tiny;
 
@@ -10,9 +10,17 @@ sub new_from_struct {
     my $struct = shift;
 
     my $wanted_class = $struct->{_class} || $role_class;
-    my %args = map { $_ => $struct->{$_} } grep {!/^_/} keys %$struct;
 
-    my $node = $wanted_class->new(%args);
+    my @args;
+    if ($struct->{_args}) {
+        @args = @{ $struct->{_args} };
+    } else {
+        @args = map { $_ => $struct->{$_} } grep {!/^_/} keys %$struct;
+    }
+
+    my $constructor = $struct->{_constructor} || "new";
+
+    my $node = $wanted_class->$constructor(@args);
 
     $node->parent($struct->{_parent}) if $struct->{_parent};
 
@@ -44,7 +52,7 @@ Role::TinyCommons::Tree::FromStruct - Role that provides methods to build tree o
 
 =head1 VERSION
 
-This document describes version 0.02 of Role::TinyCommons::Tree::FromStruct (from Perl distribution Role-TinyCommons-Tree), released on 2016-03-22.
+This document describes version 0.03 of Role::TinyCommons::Tree::FromStruct (from Perl distribution Role-TinyCommons-Tree), released on 2016-03-22.
 
 =head1 PROVIDED METHODS
 
